==> apca-w3-0.1.7.tgz: package/LICENSE.md <==
Code and documentation in this repositiory is copyright © 2019-2021 by Andrew Somers and/or Myndex™. All Rights Reserved.

# — LICENSE —

### The Short Summary:
Files in this repository are licensed to the W3/AGWG under their cooperative agreement for use with WCAG accessibility guidelines for web-based content only, and not for any other use.

______________

## W3 VERSION LICENSE:

All Files in this Repository are licensed to the W3.org under their cooperative license agreement(s):

- Reports in this Repository are licensed under the
[W3C Software and Document License](http://www.w3.org/Consortium/Legal/2015/copyright-software-and-document).
[LOCAL COPY](https://github.com/Myndex/apca-w3/blob/master/LICENSE.md#w3c-software-and-document-notice-and-license)

- Contributions to Specifications are made under the
[W3C CLA](https://www.w3.org/community/about/agreements/cla/).

- Contributions to Test Suites are made under the
[W3C 3-clause BSD License](https://www.w3.org/Consortium/Legal/2008/03-bsd-license.html)

Any files, or use cases of files, not under the W3 cooperative agreement are licensed under the AGPU v3 License, subject to disclaimers.

-----
## W3/AGWG/WCAG VERSION DISCLAIMER AND RESTRICTIONS

_**DISCLAIMER AND LIMITATIONS OF USE:**_       
**apca-w3** is an embodiment of certain suprathreshold contrast
prediction technologies and it is licensed to the W3 on a
limited basis for use in WCAG accessibility guidelines
for web content only. **apca-w3**  may be used for 
predicting contrast for web content used for that
specific purpose without royalty.

Said license excludes other use cases
not related to web content. Prohibited uses include
medical, clinical evaluation, human safety related,
aerospace, transportation, military applications, 
and uses which are not specific to web-based content
presented on self-illuminated displays or devices.

_**NO ALTERATION; KEEP CURRENT**_     
Any **apca-w3** files in this repositiory may be used or incorporated only in tools for web-based content or web related content in support of the WCAG accessibility guidelines, and such use must be without modification to the essential elements of the code or specific approved constants, except as required to port to a given language.

- Deveopers incorporating this code into their applications, widgets, or other tools, have a duty to ensure that the most recent version of this code is used in their current or any future release. 

- Breaking change exception:
    - developers do not need to incorporate future versions of **apca-w3** that have breaking changes when their release is only a minor or patch version per semantic versioning.
    - developers with minor or patch revisions are still obligated to use the latest non-breaking branch of **apca-w3**.
    - developers with a major revision per semantic versioning are obligated to use the most recent stable **apca-w3**.

_**USE OF THE APCA LOGO AND TRADEMARK**_     
Use of the APCA or "Powered by APCA" logos or trademearks are prohibited without written consent from Myndex™ Technologies, Myndex™ Research, Andrew Somers, and/or the authorized agents or assigns.
- Developers wishing to use the APCA or "Powered by APCA" logos or trademearks must submit their application or tools for qualification to be granted a limited license to use the APCA or "Powered by APCA" logos or trademearks.
- Formal details on the APCA and "Powered by APCA" qualification process are pending. In the interim, make a qualification request in the discussion tab of this repo.


## GENERAL DISCLAIMER

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

**_DISCLAIMER AND LIMITATIONS OF USE:_**

APCA is an embodiment of certain suprathreshold contrast
prediction technologies. Versions marked as licensed to 
the W3 are strictly limited to web content use only for 
supporting certain accessibility guidelines.

APCA code listed here is provided as is, with no 
warrantees expressed nor implied. We accept no 
liability for any use or misuse of the code. 
Suitability of  purpose resides with the 
integrator or end user.

Commercial use is prohibited without a written 
and signed commercial license agreement, except 
as provided by the W3 cooperative agreement for 
web content only.

Non-commercial use is permitted only for 
predicting contrast for web content, no 
other use case is authorized.

License excludes other use cases not related to web 
content. Prohibited uses include and are not limited 
to medical, clinical evaluation, human safety related, 
aerospace, transportation, military applications, and 
uses which are not specific to web-based content 
presented on self-illuminated displays or devices.

### Other licensing information

All Files _in this Repository_ that do not fall under the W3 cooperative agreement, if they exist, may have different license terms. Files, code, or other assets related to SAPC, APCA, Perceptex, or Myndex Perception Research, that are not _currently_ in this repository are not available for license or use without a written agreement.

## WITHDRAWN ASSETS
ONLY files that are currently in this repository are available for use under these license terms.

As some code herein is early beta, and there is a clear interest to prevent obsolete verions from propagating, license for use is revoked when any such asset is removed from this repositiory. Prior to revocation, files will be placed in the OBSOLETE/PENDING_DELETE folder for a period to allow time for revision. Please replace any stale assets with the revised assets herein as soon as practical.

#### The current assets shall be in:
    /dist/    
    /src/
#### Non breaking earlier versions shall be placed in:
    /LEGACY/
#### Breaking and deprecated versions shall be placed in:
    /DEPRECATED/
#### Breaking, invalid, and revoked versions shall be placed in:
    /OBSOLETE/    
    /OBSOLETE/PENDING_DELETE/

### Misc Licensing
Any files that do not fall under the above categories are per the license as indicated in each file.


-----

## W3C SOFTWARE AND DOCUMENT NOTICE AND LICENSE
This work is being provided by the copyright holders under the following license.

### License
By obtaining and/or copying this work, you (the licensee) agree that you have read, understood, and will comply with the following terms and conditions.
Permission to copy, modify, and distribute this work, with or without modification, for any purpose and without fee or royalty is hereby granted, provided that you include the following on ALL copies of the work or portions thereof, including modifications:
- The full text of this NOTICE in a location viewable to users of the redistributed or derivative work.
- Any pre-existing intellectual property disclaimers, notices, or terms and conditions. If none exist, the W3C Software and Document Short Notice should be included.
- Notice of any changes or modifications, through a copyright statement on the new code or document such as "This software or document includes material copied from or derived from [title and URI of the W3C document]. Copyright © [YEAR] W3C® (MIT, ERCIM, Keio, Beihang)."
### Disclaimers
THIS WORK IS PROVIDED "AS IS," AND COPYRIGHT HOLDERS MAKE NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY PARTICULAR PURPOSE OR THAT THE USE OF THE SOFTWARE OR DOCUMENT WILL NOT INFRINGE ANY THIRD PARTY PATENTS, COPYRIGHTS, TRADEMARKS OR OTHER RIGHTS.

COPYRIGHT HOLDERS WILL NOT BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL OR CONSEQUENTIAL DAMAGES ARISING OUT OF ANY USE OF THE SOFTWARE OR DOCUMENT.

The name and trademarks of copyright holders may NOT be used in advertising or publicity pertaining to the work without specific, written prior permission. Title to copyright in this work will at all times remain with copyright holders.

==> apca-w3-0.1.8.tgz: package/LICENSE.md <==
Code and documentation in this repositiory is copyright © 2019-2021 by Andrew Somers and/or Myndex™. All Rights Reserved.

# — LICENSE —

### The Short Summary, TL;DR:
Files in this repository are licensed to the W3/AGWG under their cooperative agreement for use with WCAG accessibility guidelines for web-delivered and web-based content only, and not for any other use.

Use of the terms "APCA", "Advanced Perceptual Contrast Algorithm", "Accessible Perceptual Contrast Algorithm", to describe any contrast method, app, or device, is only permitted for code that is maintained and up to date.

--------------
______________

## W3 VERSION LICENSE:

All Files in this Repository are licensed to the W3.org under their cooperative license agreement(s), and subject to the further limitations as defined in this license agreement.

- Reports in this Repository are licensed under the
[W3C Software and Document License](http://www.w3.org/Consortium/Legal/2015/copyright-software-and-document).
[LOCAL COPY](https://github.com/Myndex/apca-w3/blob/master/LICENSE.md#w3c-software-and-document-notice-and-license)

- Contributions to Specifications are made under the
[W3C CLA](https://www.w3.org/community/about/agreements/cla/).

- Contributions to Test Suites are made under the
[W3C 3-clause BSD License](https://www.w3.org/Consortium/Legal/2008/03-bsd-license.html)

Any files, or use cases of files, not under the W3 cooperative agreement are licensed under the AGPU v3 License, subject to disclaimers.

-----
## W3/AGWG/WCAG VERSION DISCLAIMER AND RESTRICTIONS

_**DISCLAIMER AND LIMITATIONS OF USE:**_       
**apca-w3** is an embodiment of certain suprathreshold contrast
prediction technologies and it is licensed to the W3 on a
limited basis for use in WCAG accessibility guidelines
for web content only. **apca-w3**  may be used for 
predicting contrast for web content used for that
specific purpose without royalty.

Said license excludes other use cases
not related to web content. Prohibited uses include
medical, clinical evaluation, human safety related,
aerospace, transportation, military applications, 
and uses which are not specific to web-based content
presented on self-illuminated displays or devices.

_**NO ALTERATION; KEEP CURRENT**_     
Any **apca-w3** files in this repository may be used or incorporated only in tools for web-based content or web related content in support of the WCAG accessibility guidelines, and such use must be without modification to the essential elements of the code or specific approved constants, except as required to port to a given language.

- Developers are highly encouraged to use the npm package(s) when possible:  ` npm i apca-w3 `

- Deveopers incorporating this code into their applications, widgets, or other tools, have a duty to ensure that the most recent version of this code is used in their current or any future release. 

- Breaking change exception:
    - developers do not need to incorporate future versions of **apca-w3** that have breaking changes when their release is only a minor or patch version per semantic versioning.
    - developers with minor or patch revisions are still obligated to use the latest non-breaking branch of **apca-w3**.
    - developers with a major revision per semantic versioning are obligated to use the most recent stable **apca-w3**.

_**USE OF APCA TERMINOLOGY**_     
- Use of the acronym APCA, the terms "Advanced Perceptual Contrast Algorithm", "Accessible Perceptual Contrast Algorithm", "Readability Contrast", to describe any embodyment or instantiation of contrast determination, method, or math, including the APCA code base or libraries, **is only permitted for code that is properly using the APCA algorithm, version 0.0.98G-4g or later. **

_**USE OF THE APCA LOGO AND TRADEMARK**_     
- Use of the APCA logo as shown at this repo to describe any contrast app, use, or method, or the "Powered by APCA" logo, and/or any related official logos or trademearks, **are prohibited without written consent** from Myndex™ Technologies, Myndex™ Research, Andrew Somers, and/or the authorized agents or assigns.
- Developers wishing to use the APCA or "Powered by APCA" logos or trademearks **must submit their application or tools for qualification** to be granted a limited license to use the APCA or "Powered by APCA" logos or trademearks in acssociation with their tools.
- Formal details on the APCA and "Powered by APCA" qualification process are pending. In the interim, make a qualification request in the discussion tab of this repo.


## GENERAL DISCLAIMER

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

**_DISCLAIMER AND LIMITATIONS OF USE:_**

APCA is an embodiment of certain suprathreshold contrast
prediction technologies. Versions marked as licensed to 
the W3 are strictly limited to web content use only for 
supporting certain accessibility guidelines.

APCA code listed here is provided as is, with no 
warrantees expressed nor implied. We accept no 
liability for any use or misuse of the code. 
Suitability of  purpose resides with the 
integrator or end user.

Commercial use is prohibited without a written 
and signed commercial license agreement, except 
as provided by the W3 cooperative agreement for 
web content only.

Non-commercial use is permitted only for 
predicting contrast for web content, no 
other use case is authorized.

License excludes other use cases not related to web 
content. Prohibited uses include and are not limited 
to medical, clinical evaluation, human safety related, 
aerospace, transportation, military applications, and 
uses which are not specific to web-based content 
presented on self-illuminated displays or devices.

### Other licensing information

All Files _in this Repository_ that do not fall under the W3 cooperative agreement, if they exist, may have different license terms. Files, code, or other assets related to SAPC, APCA, Perceptex, or Myndex Perception Research, that are not _currently_ in this repository are not available for license or use without a written agreement.

## WITHDRAWN ASSETS
ONLY files that are currently in this repository are available for use under these license terms.

As some code herein is early beta, and there is a clear interest to prevent obsolete verions from propagating, license for use is revoked when any such asset is removed from this repositiory. Prior to revocation, files will be placed in the OBSOLETE/PENDING_DELETE folder for a period to allow time for revision. Please replace any stale assets with the revised assets herein as soon as practical.

#### The current assets shall be in:
    /dist/    
    /src/
#### Non breaking earlier versions shall be placed in:
    /LEGACY/
#### Breaking and deprecated versions shall be placed in:
    /DEPRECATED/
#### Breaking, invalid, and revoked versions shall be placed in:
    /OBSOLETE/    
    /OBSOLETE/PENDING_DELETE/

### Misc Licensing
Any files that do not fall under the above categories are per the license as indicated in each file.


-----

## W3C SOFTWARE AND DOCUMENT NOTICE AND LICENSE
This work is being provided by the copyright holders under the following license.

### License
By obtaining and/or copying this work, you (the licensee) agree that you have read, understood, and will comply with the following terms and conditions.
Permission to copy, modify, and distribute this work, with or without modification, for any purpose and without fee or royalty is hereby granted, provided that you include the following on ALL copies of the work or portions thereof, including modifications:
- The full text of this NOTICE in a location viewable to users of the redistributed or derivative work.
- Any pre-existing intellectual property disclaimers, notices, or terms and conditions. If none exist, the W3C Software and Document Short Notice should be included.
- Notice of any changes or modifications, through a copyright statement on the new code or document such as "This software or document includes material copied from or derived from [title and URI of the W3C document]. Copyright © [YEAR] W3C® (MIT, ERCIM, Keio, Beihang)."
### Disclaimers
THIS WORK IS PROVIDED "AS IS," AND COPYRIGHT HOLDERS MAKE NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY PARTICULAR PURPOSE OR THAT THE USE OF THE SOFTWARE OR DOCUMENT WILL NOT INFRINGE ANY THIRD PARTY PATENTS, COPYRIGHTS, TRADEMARKS OR OTHER RIGHTS.

COPYRIGHT HOLDERS WILL NOT BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL OR CONSEQUENTIAL DAMAGES ARISING OUT OF ANY USE OF THE SOFTWARE OR DOCUMENT.

The name and trademarks of copyright holders may NOT be used in advertising or publicity pertaining to the work without specific, written prior permission. Title to copyright in this work will at all times remain with copyright holders.
